weaviate.schema package
=======================

.. automodule:: weaviate.schema
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   weaviate.schema.properties

Submodules
----------

weaviate.schema.crud\_schema module
-----------------------------------

.. automodule:: weaviate.schema.crud_schema
   :members:
   :undoc-members:
   :show-inheritance:
